@@ -15,9 +15,6 @@
 import os
 import sys
 
-import openstackdocstheme
-
-
 sys.path.insert(0, os.path.abspath('../..'))
 # -- General configuration ----------------------------------------------------
 
@@ -40,8 +37,8 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 # General information about the project.
-project = u'kolla-ansible'
-copyright = u'2013, OpenStack Foundation'
+project = 'Kolla Ansible'
+copyright = '2013, OpenStack Foundation'
 
 # If true, '()' will be appended to :func: etc. cross-reference text.
 add_function_parentheses = True
@@ -61,21 +58,25 @@ pygments_style = 'native'
 html_theme = 'openstackdocs'
 # html_static_path = ['static']
 
+# Add any paths that contain "extra" files, such as .htaccess or
+# robots.txt.
+html_extra_path = ['_extra']
+
 html_theme_options = {
     "show_other_versions": True,
 }
 
 # Output file base name for HTML help builder.
-htmlhelp_basename = '%sdoc' % project
+htmlhelp_basename = 'kolla-ansibledoc'
 
 # Grouping the document tree into LaTeX files. List of tuples
 # (source start file, target name, title, author, documentclass
 # [howto/manual]).
 latex_documents = [
     ('index',
-     'doc-%s.tex' % project,
-     u'%s Documentation' % project,
-     u'OpenStack Foundation', 'manual'),
+     'doc-kolla-ansible.tex',
+     'Kolla Ansible Documentation',
+     'OpenStack Foundation', 'manual'),
 ]
 
 # Disable usage of xindy https://bugzilla.redhat.com/show_bug.cgi?id=1643664
@@ -107,33 +108,3 @@ openstack_projects = [
     'swift',
     'watcher',
 ]
-
-# Global variables
-# For replacement, use in docs as |VAR_NAME| (note there's no space around variable name)
-# When adding new variables, make sure you add them to GLOBAL_VARIABLE_MAP dictionary as well
-
-KOLLA_OPENSTACK_RELEASE = openstackdocstheme.ext._get_series_name()
-
-if KOLLA_OPENSTACK_RELEASE == 'latest':
-    KOLLA_OPENSTACK_RELEASE = 'master'
-    KOLLA_BRANCH_NAME = 'master'
-else:
-    KOLLA_BRANCH_NAME = 'stable/{}'.format(KOLLA_OPENSTACK_RELEASE)
-
-GLOBAL_VARIABLE_MAP = {
-    "|KOLLA_OPENSTACK_RELEASE|": KOLLA_OPENSTACK_RELEASE,
-    "|KOLLA_BRANCH_NAME|": KOLLA_BRANCH_NAME,
-}
-
-def replace_global_vars(app, docname, source):
-    # unlike rst_epilog, replaces variables (strings) in code blocks as well
-    # thanks to https://github.com/sphinx-doc/sphinx/issues/4054#issuecomment-329097229
-    result = source[0]
-    for key in app.config.GLOBAL_VARIABLE_MAP:
-        result = result.replace(key, app.config.GLOBAL_VARIABLE_MAP[key])
-    source[0] = result
-
-
-def setup(app):
-   app.add_config_value('GLOBAL_VARIABLE_MAP', {}, True)
-   app.connect('source-read', replace_global_vars)
